@@ -59,7 +59,6 @@ class LinkStation:
         self._protocol = protocol
         self._session = session
         self._api = None
-        self._settingInfo = None
         self._cache = ExpiringDict(max_len=10, max_age_seconds=cache_age)
 
     async def get_data_with_cache_async(self):
@@ -137,25 +136,31 @@ class LinkStation:
 
             if self._is_success(settingInfo):
                 _LOGGER.debug(await settingresp.text())
-                self._settingInfo = settingInfo
+                self._cache['settingInfo'] = settingInfo
+                return settingInfo
+            return None
 
     async def get_spaces_info_desc_async(self):
-        return await self._get_settingsinfo_field("r_storage")
+        return await self._get_settingsinfo_field_async("r_storage")
 
     async def get_linkstation_name_async(self):
-        return await self._get_settingsinfo_field("r_hostname")
+        return await self._get_settingsinfo_field_async("r_hostname")
 
     async def get_linkstation_ipaddress_async(self):
-        return await self._get_settingsinfo_field("r_ipAddr:1")
+        return await self._get_settingsinfo_field_async("r_ipAddr:1")
 
     async def get_linkstation_firmware_version_async(self):
-        return await self._get_settingsinfo_field("r_version")
+        return await self._get_settingsinfo_field_async("r_version")
 
     async def _get_settingsinfo_field_async(self, fieldname):
-        if self._settingInfo == None:
-            await self._get_settings_info()
+        if self._cache.get("settingInfo") == None:
+            _LOGGER.debug("Setting Info {%s} missing from cache", fieldname)
+            settingInfo = await self._get_settings_info()
+        else:
+            settingInfo = self._cache.get("settingInfo")
 
-        for data in self._settingInfo[LINKSTATION_API_REPONSE_DATA_ELEMENT][0][
+
+        for data in settingInfo[LINKSTATION_API_REPONSE_DATA_ELEMENT][0][
             LINKSTATION_API_REPONSE_DATA_GENERALINFO_ELEMENT
         ]:
             if data["name"] == fieldname:
@@ -182,6 +187,12 @@ class LinkStation:
             if self._is_success(rebootInfo):
                 _LOGGER.info("LinkStation restarting ... ")
 
+    async def get_disks_info_with_cache_async(self):
+        if self._cache[LINKSTATION_API_REPONSE_DATA_ELEMENT]:
+            return self._cache[LINKSTATION_API_REPONSE_DATA_ELEMENT]
+
+        return await self.get_disks_info_async()
+
     async def get_disks_info_async(self):
         if self._session == None or self._session.closed:
             await self.connect_async()
